if (CMAKE_VERSION VERSION_LESS 3.10.0)
    message(FATAL_ERROR "OpenEXR Config requires CMake 3.10+")
endif()

# Protect against multiple inclusion, which would fail when already imported targets are added once more.
set(_targetsDefined)
set(_targetsNotDefined)
set(_expectedTargets)


foreach(_expectedTarget OpenEXR::Half OpenEXR::Iex OpenEXR::IexMath OpenEXR::IlmImf OpenEXR::IlmImfUtil OpenEXR::IlmThread OpenEXR::Imath OpenEXR::OpenEXR)
    list(APPEND _expectedTargets ${_expectedTarget})

    if(NOT TARGET ${_expectedTarget})
        list(APPEND _targetsNotDefined ${_expectedTarget})
    endif()

    if(TARGET ${_expectedTarget})
        list(APPEND _targetsDefined ${_expectedTarget})
    endif()
endforeach()


# All expected targets are defined, we're done
if("${_targetsDefined}" STREQUAL "${_expectedTargets}")
    unset(_targetsDefined)
    unset(_targetsNotDefined)
    unset(_expectedTargets)
    return()
endif()

if(NOT "${_targetsDefined}" STREQUAL "")
    message(FATAL_ERROR "Some (but not all) targets in this export set were already defined.\nTargets Defined: ${_targetsDefined}\nTargets not yet defined: ${_targetsNotDefined}\n")
endif()
unset(_targetsDefined)
unset(_targetsNotDefined)
unset(_expectedTargets)


# Compute the installation prefix relative to this file.
get_filename_component(_IMPORT_PREFIX "${CMAKE_CURRENT_LIST_FILE}" PATH)
get_filename_component(_IMPORT_PREFIX "${_IMPORT_PREFIX}" PATH)
if(_IMPORT_PREFIX STREQUAL "/")
    set(_IMPORT_PREFIX "")
endif()


# High Level target definitions
add_library(OpenEXR::Half SHARED IMPORTED)
set_target_properties(OpenEXR::Half
    PROPERTIES
        INTERFACE_INCLUDE_DIRECTORIES "${_IMPORT_PREFIX}/include;${_IMPORT_PREFIX}/include/OpenEXR"
)

add_library(OpenEXR::Iex SHARED IMPORTED)
set_target_properties(OpenEXR::Iex
    PROPERTIES
        INTERFACE_INCLUDE_DIRECTORIES "${_IMPORT_PREFIX}/include;${_IMPORT_PREFIX}/include/OpenEXR"
)

add_library(OpenEXR::IexMath SHARED IMPORTED)
set_target_properties(OpenEXR::IexMath
    PROPERTIES
        INTERFACE_INCLUDE_DIRECTORIES "${_IMPORT_PREFIX}/include;${_IMPORT_PREFIX}/include/OpenEXR"
        INTERFACE_LINK_LIBRARIES "OpenEXR::Iex"
)

add_library(OpenEXR::Imath SHARED IMPORTED)
set_target_properties(OpenEXR::Imath
    PROPERTIES
        INTERFACE_INCLUDE_DIRECTORIES "${_IMPORT_PREFIX}/include;${_IMPORT_PREFIX}/include/OpenEXR"
        INTERFACE_LINK_LIBRARIES "OpenEXR::Iex"
)

add_library(OpenEXR::IlmThread SHARED IMPORTED)
set_target_properties(OpenEXR::IlmThread
    PROPERTIES
        INTERFACE_INCLUDE_DIRECTORIES "${_IMPORT_PREFIX}/include;${_IMPORT_PREFIX}/include/OpenEXR"
        INTERFACE_LINK_LIBRARIES "OpenEXR::Iex;Threads::Threads"
)

add_library(OpenEXR::IlmImf SHARED IMPORTED)
set_target_properties(OpenEXR::IlmImf
    PROPERTIES
        INTERFACE_INCLUDE_DIRECTORIES "${_IMPORT_PREFIX}/include;${_IMPORT_PREFIX}/include/OpenEXR"
        INTERFACE_LINK_LIBRARIES "OpenEXR::Half;OpenEXR::Imath;OpenEXR::IlmThread;"
)

add_library(OpenEXR::IlmImfUtil SHARED IMPORTED)
set_target_properties(OpenEXR::IlmImfUtil
    PROPERTIES
        INTERFACE_INCLUDE_DIRECTORIES "${_IMPORT_PREFIX}/include;${_IMPORT_PREFIX}/include/OpenEXR"
        INTERFACE_LINK_LIBRARIES "OpenEXR::IlmImf"
)

# Dummy for being compatible with current set-up
add_library(OpenEXR::OpenEXR INTERFACE IMPORTED)
set_target_properties(OpenEXR::IlmImfUtil
    PROPERTIES
        INTERFACE_LINK_LIBRARIES "OpenEXR::IlmImf;OpenEXR::IlmImfUtil"
)

# Define binaries for targets above
set_target_properties(OpenEXR::Half
    PROPERTIES
        IMPORTED_LOCATION "${_IMPORT_PREFIX}/lib/libHalf.so"
)

set_target_properties(OpenEXR::Iex
    PROPERTIES
        IMPORTED_LOCATION "${_IMPORT_PREFIX}/lib/libIex.so"
)

set_target_properties(OpenEXR::IexMath
    PROPERTIES
        IMPORTED_LOCATION "${_IMPORT_PREFIX}/lib/libIexMath.so"
)

set_target_properties(OpenEXR::Imath
    PROPERTIES
        IMPORTED_LOCATION "${_IMPORT_PREFIX}/lib/libImath.so"
)

set_target_properties(OpenEXR::IlmThread
    PROPERTIES
        IMPORTED_LOCATION "${_IMPORT_PREFIX}/lib/libIlmThread.so"
)

set_target_properties(OpenEXR::IlmImf
    PROPERTIES
        IMPORTED_LOCATION "${_IMPORT_PREFIX}/lib/libIlmImf.so"
)

set_target_properties(OpenEXR::IlmImfUtil
    PROPERTIES
        IMPORTED_LOCATION "${_IMPORT_PREFIX}/lib/libIlmImfUtil.so"
)